@@ -10,7 +10,9 @@ use feature qw(switch);
 
 use Carp qw(carp confess);
 use Digest::SHA;
+use Encode;
 use HTTP::Response;
+use JSON::XS;
 use Any::Moose;
 use Any::Moose qw(::Util::TypeConstraints);
 use Any::Moose qw(X::NonMoose);
@@ -21,7 +23,7 @@ extends 'Net::Curl::Easy';
 use AnyEvent::Net::Curl::Const;
 use AnyEvent::Net::Curl::Queued::Stats;
 
-our $VERSION = '0.022'; # VERSION
+our $VERSION = '0.023'; # VERSION
 
 subtype 'AnyEvent::Net::Curl::Queued::Easy::URI'
     => as class_type('URI');
@@ -232,6 +234,17 @@ sub setopt {
 
         while (my ($key, $val) = each %param) {
             $key = AnyEvent::Net::Curl::Const::opt($key);
+            if (defined $key and defined $val and $key == Net::Curl::Easy::CURLOPT_POSTFIELDS and $val ne '') {
+                my $tmp;
+                eval { $tmp = encode_utf8($val); decode_json($tmp) };
+                unless ($@) {
+                    $self->SUPER::setopt(
+                        Net::Curl::Easy::CURLOPT_HTTPHEADER,
+                        [ 'Content-Type: application/json; charset=utf-8' ],
+                    );
+                    $val = $tmp;
+                }
+            }
             #$self->$orig($key, $val) if defined $key;
             $self->SUPER::setopt($key, $val) if defined $key;
         }
@@ -303,7 +316,7 @@ AnyEvent::Net::Curl::Queued::Easy - Net::Curl::Easy wrapped by Any::Moose
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -505,6 +518,9 @@ Or even shorter:
 
 Complete list of options: L<http://curl.haxx.se/libcurl/c/curl_easy_setopt.html>
 
+If C<CURLOPT_POSTFIELDS> looks like a valid JSON (validates via L<JSON::XS>),
+it is encoded as UTF-8 and C<Content-Type: application/json; charset=utf-8> header is set automatically.
+
 =head2 getinfo(VAR_NAME [, VAR_NAME])
 
 Extends L<Net::Curl::Easy> C<getinfo()> so it is able to get several variables at once;
